# from sitetree.utils import tree, item
#
# # Be sure you defined `sitetrees` in your module.
# sitetrees = (
#   # Define a tree with `tree` function.
#   tree('gfiles_all', items=[
#       # Then define items and their children with `item` function.
#       item('GFILES', 'add_run', children=[
#           item('Upload generic file', 'upload_gfile', in_menu=True, in_sitetree=True),
#           item('Show all files', 'gfile_summary',  in_menu=True, in_sitetree=True),
#       ])
#   ]),
#   # ... You can define more than one tree for your app.
# )
