{% extends 'base.html' %}
{% block sb_admin_title %} Index {% endblock sb_admin_title %}
{% block sb_admin_subheading %} <small></small> {% endblock sb_admin_subheading %}
{% block sb_admin_breadcrumb %}{% endblock sb_admin_breadcrumb %}
{% block sb_admin_breadcrumb_active %}{% endblock sb_admin_breadcrumb_active %}
{% block panel_title %}{% endblock panel_title %}
{% block content %}
      <div class="row">
                    <div class="col-lg-12">
                        <div class="panel panel-default">
                            <div class="panel-heading">
                                <h3 class="panel-title">GFile functionality</h3>
                            </div>
                            <div class="panel-body">

                                <ul>
                                    <li> <a href="{% url 'upload_gfile' %}" >Upload a file</a></li>
                                    <li> <a href="{% url 'gfile_summary' %}" >File summary</a></li>
                                    <li> <a href="{% url 'login' %}" >Login</a></li>
                                    <li> <a href="{% url 'logout' %}" >Logout</a></li>
                                    <li> <a href="{% url 'register' %}" >Register</a></li>

                                </ul>

                                <div id="morris-area-chart"></div>
                            </div>
                        </div>
                    </div>
        </div>
{% endblock content %}