{% extends 'gfiles/single_panel.html' %}
{% block panel_body %}
    <form name="form" method="post" action="" enctype="multipart/form-data">
        {% include "gfiles/formset_table.html" %}
    </form>
{% endblock %}