{% extends 'base.html' %}
{% block content %}
    <div class="row">
        <div class="col-lg-12">
            <div class="panel panel-default">
                <div class="panel-heading">
                    <h3 class="panel-title">{% block panel_title %}{% endblock panel_title %}</h3>
                </div>
                <div class="panel-body">
                    {% block panel_body %}{% endblock panel_body %}
                </div>
            </div>
        </div>
</div>
{% endblock %}