# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2018-08-22 09:47
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import gfiles.models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='GenericFile',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('data_file', models.FileField(blank=True, help_text='The reference to the uploaded data file', max_length=500, null=True, upload_to=gfiles.models.data_file_store)),
                ('original_filename', models.CharField(help_text='If a file with the same filename is uploaded at the same timea duplicate is saved with a unique name. This field is usedto keep track of the original name', max_length=500)),
                ('user', models.ForeignKey(blank=True, help_text='The user who uploaded the file', null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
        ),
        migrations.CreateModel(
            name='TrackTasks',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('taskid', models.CharField(max_length=500)),
                ('state', models.CharField(blank=True, max_length=500, null=True)),
                ('name', models.CharField(blank=True, max_length=500, null=True)),
                ('result', models.URLField(blank=True, null=True)),
                ('user', models.ForeignKey(blank=True, help_text='The user who uploaded the file', null=True, on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
        ),
    ]
