{% extends 'gfiles/table_with_filter_above.html' %}
{% block sb_admin_title %}GFile summary{% endblock sb_admin_title %}
{% block sb_admin_subheading %} <small></small> {% endblock sb_admin_subheading %}
{% block sb_admin_breadcrumb %}
    <a href="{% url "index" %}"><i class="fa fa-fw fa-dashboard"></i> Dashboard</a>
{% endblock sb_admin_breadcrumb %}
{% block sb_admin_breadcrumb_active %} / GFile Summary {% endblock sb_admin_breadcrumb_active %}
{% block panel_title %}Summary{% endblock panel_title %}