{% extends 'gfiles/simple_form.html' %}
{% load static %}
{% block sb_admin_title %}Register {% endblock sb_admin_title %}
{% block sb_admin_subheading %} <small></small> {% endblock sb_admin_subheading %}
{% block sb_admin_breadcrumb %} <a href="{% url "index" %}"><i class="fa fa-fw fa-dashboard"></i> Dashboard</a> {% endblock sb_admin_breadcrumb %}
{% block sb_admin_breadcrumb_active %} \ Register {% endblock sb_admin_breadcrumb_active %}
{% block panel_title %}{% endblock panel_title %}