from django.utils.safestring import mark_safe

EYE = mark_safe('<i class="fa fa-eye" aria-hidden="true"></i>')
DOWN = mark_safe('<i class="fa fa-fw fa-download"></i>')
PLAY = mark_safe('<i class="fa fa-fw fa-play"></i>')
SAVE = mark_safe('<i class="fa fa-fw fa-save"></i>')