{% extends 'base.html' %}
{% block sb_admin_title %}Confirm delete{% endblock sb_admin_title %}
{% block sb_admin_subheading %} <small></small> {% endblock sb_admin_subheading %}
{% block sb_admin_breadcrumb %}
    <a href="{% url "index" %}"><i class="fa fa-fw fa-dashboard"></i> Dashboard</a>
{% endblock sb_admin_breadcrumb %}
{% block sb_admin_breadcrumb_active %}{% endblock sb_admin_breadcrumb_active %}
{% block panel_title %}{% endblock panel_title %}
{% block content %}
<form action="" method="post">{% csrf_token %}
    <p>Are you sure you want to delete "{{ object }}"?</p>
    <input type="submit" value="Confirm" />
</form>
{% endblock content %}


