{% extends 'base.html' %}
{% block sb_admin_title %}Page Not Found{% endblock sb_admin_title %}
{% block sb_admin_subheading %} <small></small> {% endblock sb_admin_subheading %}
{% block sb_admin_breadcrumb %}{% endblock sb_admin_breadcrumb %}
{% block sb_admin_breadcrumb_active %}{% endblock sb_admin_breadcrumb_active %}
{% block panel_title %}{% endblock panel_title %}
{% block content %}
    <p>Page not found error 404 </p>
{% endblock content %}